{************************************************************************************************}
{                                                                                                }
{ EAX-AC3 Open AL Extension Header file                                                          }
{                                                                                                }
{ Description : The EAX-AC3 extension to Open AL provides a way to playback Dolby Digital AC3    }
{				files on systems equipped with a SB Live! card.  The packaged AC3 data is output         }
{				via the MMSYSTEM Wave device.                                                            }
{				If a SB Live! 5.1 card is installed then the AC3 data will be decoded by the             }
{				audio card.                                                                              }
{				If a legacy SB Live! card is installed then the AC3 data will be sent directly           }
{				to the S/PDIF Out.                                                                       }
{				The API supports multiple EAX-AC3 devices, and multiple AC3 streams. However             }
{				the current implementation provides one EAX-AC3 device capable of playing                }
{				one AC3 Stream at a time.                                                                }
{                                                                                                }
{ Programmer  : Daniel Peacock		Creative Labs, Inc	February 2001                              }
{                                                                                                }
{************************************************************************************************}

{********************************************************************}
{                                                                    }
{       Borland Delphi Runtime Library                               }
{       Copyright (c) 1995,2001 Borland International                }
{       Created by Project JEDI                                      }
{                                                                    }
{ The original Pascal code is: EaxAc3.pas 	                         }
{ The initial developer of the Pascal code is Amresh Ramachandran    }
{                                                                    }
{ Portions created by Amresh Ramachandran are    	  			           }
{ Copyright (C) 2001 Amresh Ramachandran (amreshr@hotmail.com)       }
{                                                                    }
{ Contributor(s): Amresh Ramachandran                                }
{                                                                    }
{       Obtained through:                                            }
{                                                                    }
{       Joint Endeavour of Delphi Innovators (Project JEDI)          }
{                                                                    }
{ You may retrieve the latest version of this file at the Project    }
{ JEDI home page, located at http://delphi-jedi.org                  }
{                                                                    }
{ The contents of this file are used with permission, subject to     }
{ the Mozilla Public License Version 1.1 (the "License"); you may    }
{ not use this file except in compliance with the License. You may   }
{ obtain a copy of the License at                                    }
{ http://www.mozilla.org/MPL/MPL-1.1.html 	                         }
{                                                                    }
{ Software distributed under the License is distributed on an 	     }
{ "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or     }
{ implied. See the License for the specific language governing       }
{ rights and limitations under the License. 				                 }
{                                                                    }
{********************************************************************}

unit EaxAc3;

{***************************************************************
 *
 * Unit Name         : EaxAc3
 * Purpose           : This is an interface unit for the use of EaxAC3 OpenAL
 *                     extentions from within Delphi and contains the
 *                     translations of eaxac3.h
 * Author            : Amresh Ramachandran amreshr@hotmail.com
 * Project name      : OpenAL EAX2.0 Extension
 * Created           : 15-Oct-2001
 * History           :
 * Thursday, October 18, 2001 13:47
 * -Changed TPosFormat enumeration values to T<value> due to case insensitivity
 * of Delphi
 *
 ****************************************************************}

interface

uses
	ALTypes;

const
	EAXAC3DLL                                       = 'eaxac3.dll';

// Success Codes
	EAXAC3_OK                                       = 0;
	EAXAC3_ALREADYPLAYING                           = 1;
	EAXAC3_EOF                                      = 2;

// Error Codes
	EAXAC3ERR_UNABLETOOPENEAXAC3DEVICE              = -1;
	EAXAC3ERR_WAVEOUTPREPAREHEADERFAILURE           = -2;
	EAXAC3ERR_OUTOFMEMORY                           = -3;
	EAXAC3ERR_FILENOTFOUND                          = -4;
	EAXAC3ERR_AC3FILETOBIG                          = -5;
	EAXAC3ERR_AC3FRAMENOTFOUND                      = -6;
	EAXAC3ERR_AC3NOTAT48KHZ                         = -7;
	EAXAC3ERR_INVALIDAC3FRAME                       = -8;
	EAXAC3ERR_AC3FILENOTOPEN                        = -9;
	EAXAC3ERR_BUFFERNOTMULTIPLEOFAC3FRAMESIZE       = -10;
	EAXAC3ERR_WAVEOUTERROR                          = -11;
	EAXAC3ERR_FAILEDTOCREATEEVENT                   = -12;
	EAXAC3ERR_EAXAC3DEVICENOTOPEN                   = -13;
	EAXAC3ERR_AC3STREAMALREADYOPEN                  = -14;
	EAXAC3ERR_POSITIONOUTOFRANGE                    = -15;
	EAXAC3ERR_NOTATSTARTOFAC3FRAME                  = -16;
	EAXAC3ERR_AC3STREAMNOTOPEN                      = -17;
	EAXAC3ERR_SETPOSITIONONLYWORKSONAC3FILES        = -18;
	EAXAC3ERR_WRITEDATAONLYWORKSWITHMEMORYSTREAMS   = -19;
	EAXAC3ERR_INVALIDPARAMETER                      = -20;
  EAXAC3ERR_NOTENOUGHAC3DATAINAC3DATABUFFER       = -21;
  EAXAC3ERR_NOTENOUGHDATA                         = -22;
  EAXAC3ERR_EAXAC3DEVICEALREADYOPEN               = -23;
  EAXAC3ERR_EAXAC3DEVICENOTFOUND                  = -24;
  EAXAC3ERR_UNSUPPORTED                           = -25;
  EAXAC3ERR_FAILEDTOCREATEFNTABLE                 = -26;
  DEFAULTEAXAC3DEVICE                             = 0;

  ENTIREBUFFER                                    = 0;
  FROMWRITECURSOR                                 = 1;

  LOOPING                                         = 1;

  ENDOFDATA                                       = 1;

// Callback messages
  EAXAC3NEEDMOREDATA                              = 0;
  EAXAC3REACHEDEND                                = 1;

  UNKNOWN                                         = 1;
  SPDIFPASSTHRU                                   = 2;
  FULLDECODE                                      = 4;

type
	PPointer = ^Pointer;
	TPosFormat = (TMILLISECONDS, TBYTE, TAC3FRAME);
	TSource = (TAC3FILE, TMEMORY);

  TEAXAC3Handle = Cardinal;

  TAC3Stream = Cardinal;

  PAC3FileInfo = ^TAC3FileInfo;
  TAC3FileInfo = packed record
    nNumOfAC3Frames: Cardinal;
    nAC3FrameSize: Cardinal;
    nSizeOfFile: Cardinal;
    nDuration: Cardinal;
    nFrequency: Cardinal;
  end;

  PEAXAC3DeviceInfo = ^TEAXAC3DeviceInfo;
  TEAXAC3DeviceInfo = packed record
//	char szDeviceName[256];
    szDeviceName: array[0..255] of char;
    uFlags: Cardinal;
    uStreams: Cardinal;
    uReserved: Cardinal;
  end;
// Callback function
  TAC3Callback = procedure(AC3Stream: TAC3Stream; msg: integer); stdcall;


  PEAXAC3FnTable = ^TEAXAC3FnTable;
  TEAXAC3FnTable = packed record
    LPEAXAC3QUERYNUMBEROFDEVICES: function: integer;
    LPEAXAC3QUERYFILE: function(szAC3Filename: PChar; lpAC3Caps: PAc3FileInfo; nSizeOfAC3FileInfoStruct: integer): HRESULT;
    LPEAXAC3QUERYMEMORY: function(lpBuffer: PChar; nSizeOfBuffer: integer; lpAC3FileInfo: PAc3FileInfo; nSizeOfAC3FileInfoStruct: integer): HRESULT;
    LPEAXAC3QUERYNOOFFRAMESREQFORPLAYBACK: function(AC3Stream: TAC3Stream): integer;
    LPEAXAC3OPENPLAYBACKDEVICE: function(EAXAC3Handle: TEAXAC3Handle): HRESULT;
    LPEAXAC3CLOSEPLAYBACKDEVICE: function(EAXAC3Handle: TEAXAC3Handle): HRESULT;
    LPEAXAC3QUERYDEVICECAPS: function(EAXAC3Handle: TEAXAC3Handle; lpEAXAC3DeviceInfo: PEAXAC3DeviceInfo; nSizeOfAC3DeviceInfoStruct: integer): HRESULT;
    LPEAXAC3GETPOSITION: function(AC3Stream: TAC3Stream; PosFormat: TPosFormat; var lpAmount: integer): HRESULT;
    LPEAXAC3SETFILEPOSITION: function(AC3Stream: TAC3Stream; PosFormat: TPosFormat; nAmount: integer): HRESULT;
		LPEAXAC3OPENSTREAM: function(EAXAC3Handle: TEAXAC3Handle; var lpAC3Stream: TAC3Stream; pAC3CallbackFn: TAC3Callback; szAC3Filename: PChar; src: TSource): HRESULT;
    LPEAXAC3CLOSESTREAM: function(AC3Stream: TAC3Stream): HRESULT;
    LPEAXAC3PREPLAYSTREAM: function(AC3Stream: TAC3Stream): HRESULT;
    LPEAXAC3PLAYSTREAM: function(AC3Stream: TAC3Stream; nLooping: integer): HRESULT;
    LPEAXAC3STOPSTREAM: function(AC3Stream: TAC3Stream): HRESULT;
    LPEAXAC3PAUSESTREAM: function(AC3Stream: TAC3Stream): HRESULT;
    LPEAXAC3RESUMESTREAM: function(AC3Stream: TAC3Stream): HRESULT;
    LPEAXAC3LOCKBUFFER: function(AC3Stream: TAC3Stream; ulBytes: Cardinal; ppvPointer1: PPointer; var pdwBytes1: Cardinal; ppvPointer: PPointer; var pdwBytes2: Cardinal; ulFlags: Cardinal): HRESULT;
    LPEAXAC3UNLOCKBUFFER: function(AC3Stream: TAC3Stream; pvPointer1: Pointer; ulSize1: Cardinal; pvPointer2: Pointer; ulSize2: Cardinal; nFinished: integer): HRESULT;
    LPEAXAC3SETPLAYBACKMODE: function(EAXAC3Handle: TEAXAC3Handle; ulPlayMode: Cardinal): HRESULT;
    LPEAXAC3GETERRORSTRING: function(hr: HRESULT; szErrorString: PChar; nSizeOfErrorString: integer): PChar;
    LPEAXAC3GETLASTERROR: function(var hr: HRESULT): HRESULT;
  end;

{$IFNDEF OPENAL}
	TEAXAC3GetFunctionTable = function(EAXAC3FnTable: PEAXAC3FnTable): HRESULT; stdcall;
{$ELSE}
  TEAXAC3GetFunctionTable = function(EAXAC3FnTable: PEAXAC3FnTable): TALBoolean; stdcall;
{$ENDIF}

// Functions exposed in the DLL

function EAXAC3GetFunctionTable(lpEAXAC3FnTable: PEAXAC3FnTable): HRESULT; stdcall; external EAXAC3DLL;

function EAXAC3QueryNumberOfDevices(): integer; stdcall; external EAXAC3DLL;

function EAXAC3QueryFile(szAC3Filename: PChar; lpAC3Caps: PAc3FileInfo; nSizeOfAC3FileInfoStruct: integer): HRESULT; stdcall; external EAXAC3DLL;

function EAXAC3QueryMemory(lpBuffer: PChar; nSizeOfBuffer: integer; lpAC3FileInfo: PAc3FileInfo; nSizeOfAC3FileInfoStruct: integer): HRESULT; stdcall; external EAXAC3DLL;

function EAXAC3QueryNoOfFramesReqForPlayback(AC3Stream: TAC3Stream): integer; stdcall; external EAXAC3DLL;

function EAXAC3OpenPlaybackDevice(EAXAC3Handle: TEAXAC3Handle): HRESULT; stdcall; external EAXAC3DLL;

function EAXAC3ClosePlaybackDevice(EAXAC3Handle: TEAXAC3Handle): HRESULT; stdcall; external EAXAC3DLL;

function EAXAC3QueryDeviceCaps(EAXAC3Handle: TEAXAC3Handle; lpEAXAC3DeviceInfo: PEAXAC3DeviceInfo; nSizeOfAC3DeviceInfoStruct: integer): HRESULT; stdcall; external EAXAC3DLL;

function EAXAC3GetPosition(AC3Stream: TAC3Stream; PosFormat: TPosFormat; var lpAmount: integer): HRESULT; stdcall; external EAXAC3DLL;

function EAXAC3SetFilePosition(AC3Stream: TAC3Stream; PosFormat: TPosFormat; nAmount: integer): HRESULT; stdcall; external EAXAC3DLL;

function EAXAC3OpenStream(EAXAC3Handle: TEAXAC3Handle; var lpAC3Stream: TAC3Stream; pAC3CallbackFn: TAC3Callback; szAC3Filename: PChar; src: TSource): HRESULT; stdcall; external EAXAC3DLL;

function EAXAC3CloseStream(AC3Stream: TAC3Stream): HRESULT; stdcall; external EAXAC3DLL;

function EAXAC3PrePlayStream(AC3Stream: TAC3Stream): HRESULT; stdcall; external EAXAC3DLL;

function EAXAC3PlayStream(AC3Stream: TAC3Stream; nLooping: integer): HRESULT; stdcall; external EAXAC3DLL;

function EAXAC3StopStream(AC3Stream: TAC3Stream): HRESULT; stdcall; external EAXAC3DLL;

function EAXAC3PauseStream(AC3Stream: TAC3Stream): HRESULT; stdcall; external EAXAC3DLL;

function EAXAC3ResumeStream(AC3Stream: TAC3Stream): HRESULT; stdcall; external EAXAC3DLL;

function EAXAC3LockBuffer(AC3Stream: TAC3Stream; ulBytes: Cardinal; ppvPointer1: PPointer; var pdwBytes1: Cardinal; ppvPointer: PPointer; var pdwBytes2: Cardinal; ulFlags: Cardinal): HRESULT; stdcall; external EAXAC3DLL;

function EAXAC3UnLockBuffer(AC3Stream: TAC3Stream; pvPointer1: Pointer; ulSize1: Cardinal; pvPointer2: Pointer; ulSize2: Cardinal; nFinished: integer): HRESULT; stdcall; external EAXAC3DLL;

function EAXAC3SetPlaybackMode(EAXAC3Handle: TEAXAC3Handle; ulPlayMode: Cardinal): HRESULT; stdcall; external EAXAC3DLL;

function EAXAC3GetErrorString(hr: HRESULT; szErrorString: PChar; nSizeOfErrorString: integer): PChar; stdcall; external EAXAC3DLL;

function EAXAC3GetLastError(var hr: HRESULT): HRESULT; stdcall; external EAXAC3DLL;


implementation

end.
